#[non_exhaustive]pub enum QueueFamilyType {
Graphics,
Compute,
Transfer,
Specific {
index: u32,
},
}Expand description
Specifies the type of queue family that a task can be executed on.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Graphics
Picks a queue family that supports graphics and transfer operations.
Compute
Picks a queue family that supports compute and transfer operations.
Transfer
Picks a queue family that supports transfer operations.
Specific
Picks the queue family of the given index. You should generally avoid this and use one of the other variants, so that the task graph compiler can pick the most optimal queue family indices that still satisfy the supported operations that the tasks require (and also, it’s more convenient that way, as there’s less to think about). Nevertheless, you may want to use this if you’re looking for some very specific outcome.