#[non_exhaustive]pub enum ImageLayoutType {
Optimal,
General,
}Expand description
Specifies which type of layout an image resource is accessed in.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Optimal
The image is accessed in an optimal layout. This is what you should be using most of the time.
The optimal layout depends on the access type. For instance, for color attachment output,
the only valid optimal layout is ColorAttachmentOptimal. For transfer sources, it’s
TransferSrcOptimal, and so on. Some access types don’t have an optimal layout for them.
In such cases, using this option makes no difference, as the general layout will
always be used.
General
The image is accessed in the general layout. This layout may be less efficient to access on some hardware than an optimal layout. However, you may still want to use it in certain cases if you want to minimize the number of layout transitions.
Implementations
Sourceimpl ImageLayoutType
impl ImageLayoutType
Sourcepub const fn is_optimal(self) -> bool
pub const fn is_optimal(self) -> bool
Returns true if the layout type is Optimal.
Sourcepub const fn is_general(self) -> bool
pub const fn is_general(self) -> bool
Returns true if the layout type is General.