pub struct Id<T = ()> { /* private fields */ }Expand description
This ID type is used throughout the crate to refer to Vulkan objects such as resource objects and their synchronization state, synchronization object state, and other state.
The type parameter denotes the type of object or state being referred to.
Note that this ID is not globally unique. It is unique in the scope of a logical device.
Implementations